==> rustc_1.70.0+dfsg1.orig.tar.xz: rustc-1.70.0-src/tests/rustdoc-js-std/parser-filter.js <==
const QUERY = [
    'fn:foo',
    'enum : foo',
    'macro<f>:foo',
    'macro!',
    'macro:mac!',
    'a::mac!',
    '-> fn:foo',
    '-> fn:foo<fn:bar>',
    '-> fn:foo<fn:bar, enum : baz::fuzz>',
];

const PARSED = [
    {
        elems: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 5,
        }],
        foundElems: 1,
        original: "fn:foo",
        returned: [],
        userQuery: "fn:foo",
        error: null,
    },
    {
        elems: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 4,
        }],
        foundElems: 1,
        original: "enum : foo",
        returned: [],
        userQuery: "enum : foo",
        error: null,
    },
    {
        elems: [],
        foundElems: 0,
        original: "macro<f>:foo",
        returned: [],
        userQuery: "macro<f>:foo",
        error: "Unexpected `<` in type filter",
    },
    {
        elems: [{
            name: "macro",
            fullPath: ["macro"],
            pathWithoutLast: [],
            pathLast: "macro",
            generics: [],
            typeFilter: 14,
        }],
        foundElems: 1,
        original: "macro!",
        returned: [],
        userQuery: "macro!",
        error: null,
    },
    {
        elems: [{
            name: "mac",
            fullPath: ["mac"],
            pathWithoutLast: [],
            pathLast: "mac",
            generics: [],
            typeFilter: 14,
        }],
        foundElems: 1,
        original: "macro:mac!",
        returned: [],
        userQuery: "macro:mac!",
        error: null,
    },
    {
        elems: [{
            name: "a::mac",
            fullPath: ["a", "mac"],
            pathWithoutLast: ["a"],
            pathLast: "mac",
            generics: [],
            typeFilter: 14,
        }],
        foundElems: 1,
        original: "a::mac!",
        returned: [],
        userQuery: "a::mac!",
        error: null,
    },
    {
        elems: [],
        foundElems: 1,
        original: "-> fn:foo",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 5,
        }],
        userQuery: "-> fn:foo",
        error: null,
    },
    {
        elems: [],
        foundElems: 1,
        original: "-> fn:foo<fn:bar>",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [
                {
                    name: "bar",
                    fullPath: ["bar"],
                    pathWithoutLast: [],
                    pathLast: "bar",
                    generics: [],
                    typeFilter: 5,
                }
            ],
            typeFilter: 5,
        }],
        userQuery: "-> fn:foo<fn:bar>",
        error: null,
    },
    {
        elems: [],
        foundElems: 1,
        original: "-> fn:foo<fn:bar, enum : baz::fuzz>",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [
                {
                    name: "bar",
                    fullPath: ["bar"],
                    pathWithoutLast: [],
                    pathLast: "bar",
                    generics: [],
                    typeFilter: 5,
                },
                {
                    name: "baz::fuzz",
                    fullPath: ["baz", "fuzz"],
                    pathWithoutLast: ["baz"],
                    pathLast: "fuzz",
                    generics: [],
                    typeFilter: 4,
                },
            ],
            typeFilter: 5,
        }],
        userQuery: "-> fn:foo<fn:bar, enum : baz::fuzz>",
        error: null,
    },
];

==> rustc_1.85.0+dfsg3.orig.tar.xz: rustc-1.85.0-src/tests/rustdoc-js-std/parser-filter.js <==
const PARSED = [
    {
        query: 'fn:foo',
        elems: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 7,
        }],
        foundElems: 1,
        userQuery: "fn:foo",
        returned: [],
        error: null,
    },
    {
        query: 'enum : foo',
        elems: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 6,
        }],
        foundElems: 1,
        userQuery: "enum : foo",
        returned: [],
        error: null,
    },
    {
        query: 'macro<f>:foo',
        elems: [],
        foundElems: 0,
        userQuery: "macro<f>:foo",
        returned: [],
        error: "Unexpected `<` in type filter (before `:`)",
    },
    {
        query: 'macro!',
        elems: [{
            name: "macro",
            fullPath: ["macro"],
            pathWithoutLast: [],
            pathLast: "macro",
            generics: [],
            typeFilter: 16,
        }],
        foundElems: 1,
        userQuery: "macro!",
        returned: [],
        error: null,
    },
    {
        query: 'macro:mac!',
        elems: [{
            name: "mac",
            fullPath: ["mac"],
            pathWithoutLast: [],
            pathLast: "mac",
            generics: [],
            typeFilter: 16,
        }],
        foundElems: 1,
        userQuery: "macro:mac!",
        returned: [],
        error: null,
    },
    {
        query: 'a::mac!',
        elems: [{
            name: "a::mac",
            fullPath: ["a", "mac"],
            pathWithoutLast: ["a"],
            pathLast: "mac",
            generics: [],
            typeFilter: 16,
        }],
        foundElems: 1,
        userQuery: "a::mac!",
        returned: [],
        error: null,
    },
    {
        query: '-> fn:foo',
        elems: [],
        foundElems: 1,
        userQuery: "-> fn:foo",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [],
            typeFilter: 7,
        }],
        error: null,
    },
    {
        query: '-> fn:foo<fn:bar>',
        elems: [],
        foundElems: 1,
        userQuery: "-> fn:foo<fn:bar>",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [
                {
                    name: "bar",
                    fullPath: ["bar"],
                    pathWithoutLast: [],
                    pathLast: "bar",
                    generics: [],
                    typeFilter: 7,
                }
            ],
            typeFilter: 7,
        }],
        error: null,
    },
    {
        query: '-> fn:foo<fn:bar, enum : baz::fuzz>',
        elems: [],
        foundElems: 1,
        userQuery: "-> fn:foo<fn:bar, enum : baz::fuzz>",
        returned: [{
            name: "foo",
            fullPath: ["foo"],
            pathWithoutLast: [],
            pathLast: "foo",
            generics: [
                {
                    name: "bar",
                    fullPath: ["bar"],
                    pathWithoutLast: [],
                    pathLast: "bar",
                    generics: [],
                    typeFilter: 7,
                },
                {
                    name: "baz::fuzz",
                    fullPath: ["baz", "fuzz"],
                    pathWithoutLast: ["baz"],
                    pathLast: "fuzz",
                    generics: [],
                    typeFilter: 6,
                },
            ],
            typeFilter: 7,
        }],
        error: null,
    },
];
